@@ -6,7 +6,7 @@
 ;; Author: Le Wang <l26wang@gmail.com>
 ;; Maintainer: Sean Whitton <spwhitton@spwhitton.name>
 ;; Package-Requires: ((emacs "24.1"))
-;; Version: 1.0
+;; Version: 1.1
 ;; URL: https://elpa.nongnu.org/nongnu/ws-butler.html
 ;; Keywords: text
 
@@ -33,6 +33,10 @@
 
 ;;; News:
 
+;; Ver 1.1 2025/02/21 Sean Whitton
+;;     Exempt `compilation-mode' from `ws-butler-global-mode' by default.
+;;     Clarify docstring of `ws-butler-global-exempt-modes'.
+;;
 ;; Ver 1.0 2025/02/18 Sean Whitton
 ;;     Take over maintenance; maintain out of nongnu-elpa.git.
 ;;     Bump to version 1.0: core functionality not expected to change.
@@ -71,12 +75,14 @@ If `smart-tabs-mode' is enabled, these conversions are suppressed."
     comint-mode
     term-mode
     eshell-mode
+    compilation-mode
 
     diff-mode
     message-mode
     markdown-mode)
   "Trailing whitespace-significant major modes.
-`ws-butler-mode' will not activate in these modes or in their derivatives."
+`ws-butler-global-mode' will not activate `ws-butler-mode' in these modes,
+or in their derivatives."
   :type '(repeat (symbol :tag "Major mode"))
   :group 'ws-butler)
 
@@ -94,8 +100,7 @@ trimmed.  The default is to trim everywhere."
   "Like `save-excursion' and `save-restriction', but only once.
 If within the scope of another use of this macro, just evaluate FORMS."
   (declare (debug (body)))
-  `(if (and (boundp 'ws-butler-saved)
-            ws-butler-saved)
+  `(if (bound-and-true-p ws-butler-saved)
        (progn
          ,@forms)
      (let ((ws-butler-saved t))
@@ -207,9 +212,8 @@ Respects `ws-butler-keep-whitespace-before-point', which see."
   (when ws-butler-keep-whitespace-before-point
     (ws-butler-with-save
      (widen)
-     (setq ws-butler-presave-coord (list
-                                    (line-number-at-pos (point))
-                                    (current-column)))))
+     (setq ws-butler-presave-coord (list (line-number-at-pos (point))
+					 (current-column)))))
   (let (last-end)
     (ws-butler-map-changes
      (lambda (_prop beg end)
@@ -291,6 +295,19 @@ only for lines modified by you."
     (remove-hook 'after-revert-hook #'ws-butler-after-save t)
     (remove-hook 'edit-server-done-hook #'ws-butler-before-save t)))
 
+;; It would be better to use a `:predicate' parameter to
+;; `define-globalized-minor-mode', and mark `ws-butler-global-exempt-modes'
+;; obsolete.  We could probably still honour a user's custom
+;; `ws-butler-global-exempt-modes', if it was set, in this TURN-ON function.
+;; Here is an example of a useful custom, user-specified predicate:
+;;
+;;     '((not markdown-mode
+;;            message-mode
+;;            lisp-interaction-mode)
+;;       prog-mode conf-mode text-mode)
+;;
+;; However, this would mean bumping our minimum required Emacs version to
+;; 28.1.  For a package like this one, I think it is too soon for that.
 (defun ws-butler--global-mode-turn-on ()
   "Enable `ws-butler-mode' unless current major mode is exempt."
   (unless (apply #'derived-mode-p ws-butler-global-exempt-modes)
